@@ -1,6 +1,9 @@
 import pytest
 
-def _api(access_token='__MASTODON_PY_TEST_ACCESS_TOKEN', version="3.1.1", version_check_mode="created"):
+# Set this to True to debug issues with tests
+DEBUG_REQUESTS = True
+
+def _api(access_token='__MASTODON_PY_TEST_ACCESS_TOKEN', version="4.0.0", version_check_mode="created"):
     import mastodon
     return mastodon.Mastodon(
             api_base_url='http://localhost:3000',
@@ -8,7 +11,9 @@ def _api(access_token='__MASTODON_PY_TEST_ACCESS_TOKEN', version="3.1.1", versio
             client_secret='__MASTODON_PY_TEST_CLIENT_SECRET',
             access_token=access_token,
             mastodon_version=version,
-            version_check_mode=version_check_mode)
+            version_check_mode=version_check_mode,
+            user_agent='tests/v311',
+            debug_requests=DEBUG_REQUESTS)
 
 
 @pytest.fixture
@@ -43,6 +48,12 @@ def status2(api):
     yield _status
     api.status_delete(_status['id'])
 
+@pytest.fixture
+def status3(api2):
+    _status = api2.status_post('Toot, finally!')
+    yield _status
+    api2.status_delete(_status['id'])
+
 @pytest.fixture(scope="module")
 def vcr_config():
     return dict(
