@@ -22,14 +22,37 @@ def test_log_in_none(api_anonymous):
     with pytest.raises(MastodonIllegalArgumentError):
         api_anonymous.log_in()
 
-
 @pytest.mark.vcr()
 def test_log_in_password(api_anonymous):
     token = api_anonymous.log_in(
-        username='admin@localhost',
-        password='mastodonadmin')
+        username='mastodonpy_test_2@localhost:3000',
+        password='5fc638e0e53eafd9c4145b6bb852667d'
+    )
     assert token
 
+@pytest.mark.vcr()
+def test_revoke(api_anonymous):
+    token = api_anonymous.log_in(
+        username='mastodonpy_test_2@localhost:3000',
+        password='5fc638e0e53eafd9c4145b6bb852667d',
+    )
+    api_anonymous.revoke_access_token()
+
+    try:
+        api_anonymous.toot("illegal access detected")
+        assert False
+    except Exception as e:
+        print(e)
+        pass
+
+    api_revoked_token = Mastodon(access_token = token, api_base_url='http://localhost:3000')
+    try:
+        api_revoked_token.toot("illegal access detected")
+        assert False
+    except Exception as e:
+        print(e)
+        pass
+
 @pytest.mark.vcr()
 def test_log_in_password_incorrect(api_anonymous):
     with pytest.raises(MastodonIllegalArgumentError):
@@ -41,8 +64,8 @@ def test_log_in_password_incorrect(api_anonymous):
 def test_log_in_password_to_file(api_anonymous, tmpdir):
     filepath = tmpdir.join('token')
     api_anonymous.log_in(
-        username='admin@localhost',
-        password='mastodonadmin',
+        username='mastodonpy_test_2@localhost:3000',
+        password='5fc638e0e53eafd9c4145b6bb852667d',
         to_file=str(filepath))
     token = filepath.read_text('UTF-8').rstrip().split("\n")[0]
     assert token
