@@ -31,7 +31,7 @@ def test_create_app(mocker, to_file=None, redirect_uris=None, website=None):
 def test_create_app_to_file(mocker, tmpdir):
     filepath = tmpdir.join('credentials')
     test_create_app(mocker, to_file=str(filepath))
-    assert filepath.read_text('UTF-8') == "foo\nbar\nhttps://example.com\n"
+    assert filepath.read_text('UTF-8') == "foo\nbar\nhttps://example.com\nMastodon.py test suite\n"
 
 def test_create_app_redirect_uris(mocker):
     test_create_app(mocker, redirect_uris='http://example.net')
@@ -66,4 +66,28 @@ def test_app_account_create():
     )
     test_token = test_app_api.create_account("coolguy" + suffix, "swordfish", "email@localhost" + suffix, agreement=True)
     assert test_token
+
+    # We can also test resending (marginally)
+    test_app_api.email_resend_confirmation()
+
+@pytest.mark.vcr(match_on=['path'])
+def test_app_account_create_invalid():    
+    suffix = str(time.time()).replace(".", "")[-5:]
     
+    test_app = test_app = Mastodon.create_app(
+        "mastodon.py generated test app", 
+        api_base_url="http://localhost:3000/"
+    )
+    
+    test_app_api = Mastodon(
+        test_app[0], 
+        test_app[1], 
+        api_base_url="http://localhost:3000/"
+    )
+    test_token, error = test_app_api.create_account("coolguy" + suffix, "", "email@localhost" + suffix, agreement=False, return_detailed_error=True)
+    assert test_token is None
+    assert "details" in error
+    assert "password" in error.details
+    assert "password" in error.details
+    assert not "username" in error.details
+    
\ No newline at end of file
