@@ -36,6 +36,17 @@ def test_fetch_next_previous(api):
 
 @pytest.mark.vcr()
 def test_fetch_next_previous_from_pagination_info(api):
+    account = api.account_verify_credentials()
+    with many_statuses(api):
+        statuses = api.account_statuses(account['id'], limit=5)
+        next_statuses = api.fetch_next(statuses._pagination_next)
+        assert next_statuses
+        previous_statuses = api.fetch_previous(next_statuses._pagination_prev)
+        assert previous_statuses
+
+@pytest.mark.vcr()
+def test_fetch_next_previous_from_pagination_info_oldstyle(api):
+    # Old style compatibility mode. The storage in the list items is not anymore internally used.
     account = api.account_verify_credentials()
     with many_statuses(api):
         statuses = api.account_statuses(account['id'], limit=5)
@@ -59,6 +70,17 @@ def test_fetch_next_previous_from_pagination_info_old_pagination(api):
     with vcr.use_cassette('test_fetch_next_previous_from_pagination_info.yaml', cassette_library_dir='tests/cassettes_old_pagination', record_mode='none'):
         account = api.account_verify_credentials()
         
+        with many_statuses(api):
+            statuses = api.account_statuses(account['id'], limit=5)
+            next_statuses = api.fetch_next(statuses._pagination_next)
+            assert next_statuses
+            previous_statuses = api.fetch_previous(next_statuses._pagination_prev)
+            assert previous_statuses
+
+    # Old style compatibility mode. The storage in the list items is not anymore internally used.
+    with vcr.use_cassette('test_fetch_next_previous_from_pagination_info.yaml', cassette_library_dir='tests/cassettes_old_pagination', record_mode='none'):
+        account = api.account_verify_credentials()
+
         with many_statuses(api):
             statuses = api.account_statuses(account['id'], limit=5)
             next_statuses = api.fetch_next(statuses[-1]._pagination_next)
@@ -86,5 +108,9 @@ def test_link_headers(api):
     })
 
     resp = api.timeline_hashtag(UNLIKELY_HASHTAG)
+    assert resp._pagination_next['max_id'] == _id
+    assert resp._pagination_prev['since_id'] == _id
+
+    # Old style compatibility mode. The storage in the list items is not anymore internally used.
     assert resp[0]._pagination_next['max_id'] == _id
-    assert resp[0]._pagination_prev['since_id'] == _id
+    assert resp[0]._pagination_prev['since_id'] == _id
\ No newline at end of file
